pub mod equation_2_1;
pub mod equation_2_10;
pub mod equation_2_11;
pub mod equation_2_12;
pub mod equation_2_13;
pub mod equation_2_2;
pub mod equation_2_3;
pub mod equation_2_4;
pub mod equation_2_5;
pub mod equation_2_6;
pub mod equation_2_7;
pub mod equation_2_8;
pub mod equation_2_9;
